@@ -17,9 +17,9 @@ class Step(object):
     def _set_step_attrs(self, local_attrs):
         """this method set _givens, _whens and _thens to the class,
         because the steps are called while the class is been defined"""
-        for private_step in ['_givens', '_whens', '_thens']:
-            if not private_step in local_attrs:
-                local_attrs[private_step] = []
+        attr_name = '_%ss' % self.name
+        if not attr_name in local_attrs:
+            local_attrs[attr_name] = []
 
     def __call__(self, method=None):
         del self._steps[-1]
