@@ -8,14 +8,22 @@ from output import OutputWriter, colored
 import sys
 import re
 
+
 __all__ = [ 'Story', 'Historia', ]
 
+
 class InvalidStoryHeader(Exception):
     '''Invalid Story Header!'''
 
+
 class ScenarioNotFound(Exception):
     '''Scenario not found!'''
 
+
+class Namespace(object):
+    pass
+
+
 class Story(object):
     output = sys.stdout
     colored = True
@@ -26,6 +34,7 @@ class Story(object):
     error_color = 'red'
     pending_color = 'blue'
     title = ''
+    namespace = None
 
     def __init__(self):
         self._language = StoryLanguage(self.__class__.language)
@@ -148,9 +157,9 @@ class Story(object):
                                 '%s: %s\n' % (self._language['story'],
                                               self._title),
                                                   self.template_color))
-        for line in self.__doc__.split('\n'):
+        for line in [line.strip() for line in self.__doc__.split('\n') if line.strip()]:
             self._output.write(self._colored(
-                                '  ' + line.strip() + '\n', self.template_color))
+                                '  ' + line + '\n', self.template_color))
 
     @classmethod
     def run(instance_or_class):
@@ -165,23 +174,48 @@ class Story(object):
         number_of_scenarios = len(self._scenarios)
         number_of_failures = number_of_errors = number_of_pendings = 0
 
-        for scenario, number in zip(self._scenarios, range(1, len(self._scenarios)+1)):
-            self._output.write(self._colored('\n  %s %d: %s\n' % (
-                                                self._language['scenario'],
-                                                number,
-                                                scenario.title),
-                                                    self.template_color))
-            failures, errors, pendings = scenario.run()
-            number_of_failures += len(failures)
-            number_of_errors += len(errors)
-            number_of_pendings += len(pendings)
+        self.namespace = Namespace()
+        self.before_all(self.namespace)
+         
+        status_code = True
+        try:
+          for scenario, number in zip(self._scenarios, range(1, len(self._scenarios)+1)):
+              self._output.write(self._colored('\n  %s %d: %s\n' % (
+                                                  self._language['scenario'],
+                                                  number,
+                                                  scenario.title),
+                                                      self.template_color))
+              self.before_each(scenario)
+              failures, errors, pendings = scenario.run()
+              self.after_each(scenario)
+              number_of_failures += len(failures)
+              number_of_errors += len(errors)
+              number_of_pendings += len(pendings)
+              status_code = status_code and len(errors) == 0 and len(failures) == 0
+
+          self._output_writer.output_statistics(number_of_scenarios,
+                                 number_of_failures,
+                                 number_of_errors,
+                                 number_of_pendings,
+                                 self.template_color)
+          self._close_output_file_stream()
+          return status_code
+        finally:
+          self.after_all(self.namespace)
+
+
+    def before_all(self, scenario):
+        pass
+
+    def before_each(self, scenario):
+        pass
+
+    def after_all(self, scenario):
+        pass
+
+    def after_each(self, scenario):
+        pass
 
-        self._output_writer.output_statistics(number_of_scenarios,
-                               number_of_failures,
-                               number_of_errors,
-                               number_of_pendings,
-                               self.template_color)
-        self._close_output_file_stream()
 
 class Historia(Story):
     saida = sys.stdout
@@ -197,4 +231,4 @@ class Historia(Story):
 
     @classmethod
     def rodar(cls):
-        super(Historia, cls).run()
+        return super(Historia, cls).run()
